@@ -1300,6 +1300,8 @@ cph_mechanism_job_cancel_purge (CphIfaceMechanism     *object,
                                         _cph_mechanism_return_error (mechanism, TRUE));
                         goto out;
                 }
+                default:
+                        g_warning("Invalid value in enum");
         }
 
         ret = cph_cups_job_cancel (mechanism->priv->cups, id, purge, user_name);
@@ -1364,6 +1366,8 @@ cph_mechanism_job_restart (CphIfaceMechanism     *object,
                                         _cph_mechanism_return_error (mechanism, TRUE));
                         goto out;
                 }
+                default:
+                        g_warning("Invalid value in enum");
         }
 
         ret = cph_cups_job_restart (mechanism->priv->cups, id, user_name);
@@ -1419,6 +1423,8 @@ cph_mechanism_job_set_hold_until (CphIfaceMechanism     *object,
                                         _cph_mechanism_return_error (mechanism, TRUE));
                         goto out;
                 }
+                default:
+                        g_warning("Invalid value in enum");
         }
 
         ret = cph_cups_job_set_hold_until (mechanism->priv->cups, id, job_hold_until, user_name);
